pub fn format(source: &str, options: FormatOptions) -> Result<String>Expand description
Returns the input source formatted according to the provided options
pub fn format(source: &str, options: FormatOptions) -> Result<String>Returns the input source formatted according to the provided options